"""
Exposes 'collections.abc' as 'abc' as found in Python 3.4

>>> from py33compat.collections import abc
>>> 'Sequence' in vars(abc)
True
>>> import types
>>> from py33compat import collections
>>> isinstance(collections.abc, types.ModuleType)
True
"""

from __future__ import absolute_import

try:
	from collections import abc
except ImportError:
	import collections as abc


__all__ = ['abc']



try:
	from functools import lru_cache, update_wrapper, wraps
except ImportError:
	from .cache import lru_cache
	from ._functools_wraps import update_wrapper, wraps


__all__ = ['lru_cache', 'update_wrapper', 'wraps']



"""
Downgrade to pip 19.0 before installing requirements, working
around limitations introduced in 19.1 (ref
https://github.com/pypa/pip/issues/6434)
"""

import sys
import subprocess
import shlex


def main():
	subprocess.check_call(shlex.split(
		'python -m pip install pip<19.1'
	))
	subprocess.check_call(shlex.split(
		'python -m pip install') + sys.argv[1:])


__name__ == '__main__' and main()
